Clazz.declarePackage("J.api");
Clazz.declareInterface(J.api, "JmolRendererInterface", J.api.JmolGraphicsInterface);
;//5.0.1-v7 Mon Jan 19 16:49:55 CST 2026
